@@ -70,10 +70,14 @@ AbstractDiskWriter::~AbstractDiskWriter()
 
 void AbstractDiskWriter::openFile(uint64_t totalLength)
 {
-  if(File(filename_).exists()) {
+  try {
     openExistingFile(totalLength);
-  } else {
-    initAndOpenFile(totalLength);
+  } catch(RecoverableException& e) {
+    if(e.getErrno() == ENOENT) {
+      initAndOpenFile(totalLength);
+    } else {
+      throw;
+    }
   }
 }
 
@@ -87,11 +91,6 @@ void AbstractDiskWriter::closeFile()
 
 void AbstractDiskWriter::openExistingFile(uint64_t totalLength)
 {
-  if(!File(filename_).exists()) {
-    throw DL_ABORT_EX
-      (StringFormat(EX_FILE_OPEN, filename_.c_str(), MSG_FILE_NOT_FOUND).str());
-  }
-
   int flags = O_BINARY;
   if(readOnly_) {
     flags |= O_RDONLY;
@@ -100,8 +99,10 @@ void AbstractDiskWriter::openExistingFile(uint64_t totalLength)
   }
 
   if((fd_ = open(filename_.c_str(), flags, OPEN_MODE)) < 0) {
-    throw DL_ABORT_EX
-      (StringFormat(EX_FILE_OPEN, filename_.c_str(), strerror(errno)).str());
+    throw DL_ABORT_EX2
+      (errno,
+       StringFormat
+       (EX_FILE_OPEN, filename_.c_str(), strerror(errno)).str());
   }
 }
 
@@ -111,8 +112,9 @@ void AbstractDiskWriter::createFile(int addFlags)
   util::mkdirs(File(filename_).getDirname());
   if((fd_ = open(filename_.c_str(), O_CREAT|O_RDWR|O_TRUNC|O_BINARY|addFlags,
                 OPEN_MODE)) < 0) {
-    throw DL_ABORT_EX(StringFormat(EX_FILE_OPEN,
-                                   filename_.c_str(), strerror(errno)).str());
+    throw DL_ABORT_EX2
+      (errno,
+       StringFormat(EX_FILE_OPEN, filename_.c_str(), strerror(errno)).str());
   }  
 }
 
@@ -193,19 +195,31 @@ void AbstractDiskWriter::truncate(uint64_t length)
 #endif
 }
 
-#ifdef HAVE_POSIX_FALLOCATE
 void AbstractDiskWriter::allocate(off_t offset, uint64_t length)
 {
+#ifdef  HAVE_SOME_FALLOCATE
   if(fd_ == -1) {
     throw DL_ABORT_EX("File not yet opened.");
   }
+# ifdef HAVE_FALLOCATE
+  // For linux, we use fallocate to detect file system supports
+  // fallocate or not.
+  int r = fallocate(fd_, 0, offset, length);
+  if(r == -1) {
+    throw DL_ABORT_EX(StringFormat("fallocate failed. cause: %s",
+                                   strerror(errno)).str());
+  }
+# elif HAVE_POSIX_FALLOCATE
   int r = posix_fallocate(fd_, offset, length);
   if(r != 0) {
     throw DL_ABORT_EX(StringFormat("posix_fallocate failed. cause: %s",
                                    strerror(r)).str());
   }
+# else
+#  error "no *_fallocate function available."
+# endif
+#endif // HAVE_SOME_FALLOCATE
 }
-#endif // HAVE_POSIX_FALLOCATE
 
 uint64_t AbstractDiskWriter::size()
 {
