@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_LEECHER_STATE_CHOKE_H_
-#define _D_BT_LEECHER_STATE_CHOKE_H_
+#ifndef D_BT_LEECHER_STATE_CHOKE_H
+#define D_BT_LEECHER_STATE_CHOKE_H
 
 #include "common.h"
 
@@ -86,8 +86,25 @@ private:
 
   void regularUnchoke(std::vector<PeerEntry>& peerEntries);
 
-  friend class PeerFilter;
-  friend class BtLeecherStateChokeGenPeerEntry;
+  class PeerFilter {
+  private:
+    bool amChoking_;
+    bool peerInterested_;
+  public:
+    PeerFilter(bool amChoking, bool peerInterested):
+      amChoking_(amChoking),
+      peerInterested_(peerInterested) {}
+
+    bool operator()(const PeerEntry& peerEntry) const;
+  };
+
+  class BtLeecherStateChokeGenPeerEntry {
+  public:
+    PeerEntry operator()(const SharedHandle<Peer>& peer) const
+    {
+      return PeerEntry(peer);
+    }
+  };
 public:
   BtLeecherStateChoke();
 
@@ -100,4 +117,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_BT_LEECHER_STATE_CHOKE_H_
+#endif // D_BT_LEECHER_STATE_CHOKE_H
