@@ -32,10 +32,11 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DEFAULT_BT_MESSAGE_FACTORY_H_
-#define _D_DEFAULT_BT_MESSAGE_FACTORY_H_
+#ifndef D_DEFAULT_BT_MESSAGE_FACTORY_H
+#define D_DEFAULT_BT_MESSAGE_FACTORY_H
 
 #include "BtMessageFactory.h"
+#include "Command.h"
 
 namespace aria2 {
 
@@ -55,31 +56,31 @@ class DHTTaskFactory;
 
 class DefaultBtMessageFactory : public BtMessageFactory {
 private:
-  int32_t cuid;
-  SharedHandle<DownloadContext> _downloadContext;
-  SharedHandle<PieceStorage> _pieceStorage;
-  SharedHandle<PeerStorage> _peerStorage;
-  SharedHandle<Peer> peer;
+  cuid_t cuid_;
+  SharedHandle<DownloadContext> downloadContext_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  SharedHandle<PeerStorage> peerStorage_;
+  SharedHandle<Peer> peer_;
 
-  bool _dhtEnabled;
+  bool dhtEnabled_;
 
-  WeakHandle<BtMessageDispatcher> dispatcher;
+  WeakHandle<BtMessageDispatcher> dispatcher_;
 
-  WeakHandle<BtRequestFactory> requestFactory;
+  WeakHandle<BtRequestFactory> requestFactory_;
 
-  WeakHandle<PeerConnection> peerConnection;
+  WeakHandle<PeerConnection> peerConnection_;
 
-  SharedHandle<ExtensionMessageFactory> _extensionMessageFactory;
+  SharedHandle<ExtensionMessageFactory> extensionMessageFactory_;
 
-  WeakHandle<DHTNode> _localNode;
+  WeakHandle<DHTNode> localNode_;
 
-  WeakHandle<DHTRoutingTable> _routingTable;
+  WeakHandle<DHTRoutingTable> routingTable_;
 
-  WeakHandle<DHTTaskQueue> _taskQueue;
+  WeakHandle<DHTTaskQueue> taskQueue_;
 
-  WeakHandle<DHTTaskFactory> _taskFactory;
+  WeakHandle<DHTTaskFactory> taskFactory_;
 
-  bool _metadataGetMode;
+  bool metadataGetMode_;
 
   void setCommonProperty(const SharedHandle<AbstractBtMessage>& msg);
 public:
@@ -142,15 +143,17 @@ public:
 
   void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
 
-  void setCuid(int32_t cuid) {
-    this->cuid = cuid;
+  void setCuid(cuid_t cuid)
+  {
+    cuid_ = cuid;
   }
 
   void setDHTEnabled(bool enabled) {
-    _dhtEnabled = enabled;
+    dhtEnabled_ = enabled;
   }
 
-  void setBtMessageDispatcher(const WeakHandle<BtMessageDispatcher>& dispatcher);
+  void setBtMessageDispatcher
+  (const WeakHandle<BtMessageDispatcher>& dispatcher);
   
   void setBtRequestFactory(const WeakHandle<BtRequestFactory>& factory);
 
@@ -169,7 +172,7 @@ public:
 
   void enableMetadataGetMode()
   {
-    _metadataGetMode = true;
+    metadataGetMode_ = true;
   }
 };
 
@@ -177,4 +180,4 @@ typedef SharedHandle<DefaultBtMessageFactory> DefaultBtMessageFactoryHandle;
 
 } // namespace aria2
 
-#endif // _D_DEFAULT_BT_MESSAGE_FACTORY_H_
+#endif // D_DEFAULT_BT_MESSAGE_FACTORY_H
