@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_MULTI_DISK_ADAPTOR_H_
-#define _D_MULTI_DISK_ADAPTOR_H_
+#ifndef D_MULTI_DISK_ADAPTOR_H
+#define D_MULTI_DISK_ADAPTOR_H
 
 #include "DiskAdaptor.h"
 
@@ -45,16 +45,14 @@ class DiskWriter;
 
 class DiskWriterEntry {
 private:
-  SharedHandle<FileEntry> fileEntry;
-  SharedHandle<DiskWriter> diskWriter;
-  bool _open;
-  bool _directIO;
-  bool _needsFileAllocation;
+  SharedHandle<FileEntry> fileEntry_;
+  SharedHandle<DiskWriter> diskWriter_;
+  bool open_;
+  bool directIO_;
+  bool needsFileAllocation_;
 public:
   DiskWriterEntry(const SharedHandle<FileEntry>& fileEntry);
 
-  ~DiskWriterEntry();
-
   const std::string& getFilePath() const;
 
   void initAndOpenFile();
@@ -67,7 +65,7 @@ public:
 
   bool isOpen() const
   {
-    return _open;
+    return open_;
   }
 
   bool fileExists();
@@ -76,36 +74,36 @@ public:
 
   const SharedHandle<FileEntry>& getFileEntry() const
   {
-    return fileEntry;
+    return fileEntry_;
   }
 
   void setDiskWriter(const SharedHandle<DiskWriter>& diskWriter);
 
   const SharedHandle<DiskWriter>& getDiskWriter() const
   {
-    return diskWriter;
+    return diskWriter_;
   }
 
   bool operator<(const DiskWriterEntry& entry) const;
 
-  // Set _directIO to true.
+  // Set directIO_ to true.
   // Additionally, if diskWriter is opened, diskWriter->enableDirectIO() is
   // called.
   void enableDirectIO();
 
-  // Set _directIO to false.
+  // Set directIO_ to false.
   // Additionally, if diskWriter is opened, diskWriter->disableDirectIO() is
   // called.
   void disableDirectIO();
 
   bool needsFileAllocation() const
   {
-    return _needsFileAllocation;
+    return needsFileAllocation_;
   }
 
   void needsFileAllocation(bool f)
   {
-    _needsFileAllocation = f;
+    needsFileAllocation_ = f;
   }
 
 };
@@ -117,16 +115,16 @@ typedef std::vector<DiskWriterEntryHandle> DiskWriterEntries;
 class MultiDiskAdaptor : public DiskAdaptor {
   friend class MultiFileAllocationIterator;
 private:
-  size_t pieceLength;
-  DiskWriterEntries diskWriterEntries;
+  size_t pieceLength_;
+  DiskWriterEntries diskWriterEntries_;
 
-  std::vector<SharedHandle<DiskWriterEntry> > _openedDiskWriterEntries;
+  std::vector<SharedHandle<DiskWriterEntry> > openedDiskWriterEntries_;
 
-  size_t _maxOpenFiles;
+  size_t maxOpenFiles_;
 
-  bool _directIOAllowed;
+  bool directIOAllowed_;
 
-  bool _readOnly;
+  bool readOnly_;
 
   void resetDiskWriterEntries();
 
@@ -140,8 +138,6 @@ private:
 public:
   MultiDiskAdaptor();
 
-  virtual ~MultiDiskAdaptor();
-
   virtual void initAndOpenFile();
 
   virtual void openFile();
@@ -169,19 +165,20 @@ public:
 
   virtual void disableReadOnly();
 
-  virtual bool isReadOnlyEnabled() const { return _readOnly; }
+  virtual bool isReadOnlyEnabled() const { return readOnly_; }
 
-  void setPieceLength(size_t pieceLength) {
-    this->pieceLength = pieceLength;
+  void setPieceLength(size_t pieceLength)
+  {
+    pieceLength_ = pieceLength;
   }
 
   size_t getPieceLength() const {
-    return pieceLength;
+    return pieceLength_;
   }
 
   void allowDirectIO()
   {
-    _directIOAllowed = true;
+    directIOAllowed_ = true;
   }
 
   virtual void cutTrailingGarbage();
@@ -193,7 +190,7 @@ public:
   const std::vector<SharedHandle<DiskWriterEntry> >&
   getDiskWriterEntries() const
   {
-    return diskWriterEntries;
+    return diskWriterEntries_;
   }
 
 };
@@ -202,4 +199,4 @@ typedef SharedHandle<MultiDiskAdaptor> MultiDiskAdaptorHandle;
 
 } // namespace aria2
 
-#endif // _D_MULTI_DISK_ADAPTOR_H_
+#endif // D_MULTI_DISK_ADAPTOR_H
