@@ -35,6 +35,7 @@
 #include "Sqlite3CookieParser.h"
 
 #include <cstring>
+#include <limits>
 
 #include "DlAbortEx.h"
 #include "util.h"
@@ -69,7 +70,8 @@ Sqlite3CookieParser::~Sqlite3CookieParser()
   sqlite3_close(db_);
 }
 
-static std::string toString(const char* str)
+namespace {
+std::string toString(const char* str)
 {
   if(str) {
     return str;
@@ -77,20 +79,25 @@ static std::string toString(const char* str)
     return A2STR::NIL;
   }
 }
+} // namespace
 
-static bool parseTime(int64_t& time, const std::string& s)
+namespace {
+bool parseTime(int64_t& time, const std::string& s)
 {
   if(!util::parseLLIntNoThrow(time, s)) {
     return false;
   }
-  if(sizeof(time_t) == 4 && time > INT32_MAX) {
-    time = INT32_MAX;
+  if(std::numeric_limits<time_t>::max() < time) {
+    time = std::numeric_limits<time_t>::max();
+  } else if(std::numeric_limits<time_t>::min() > time) {
+    time = std::numeric_limits<time_t>::min();
   }
   return true;
 }
+} // namespace
 
-static int cookieRowMapper(void* data, int columns,
-                           char** values, char** names)
+namespace {
+int cookieRowMapper(void* data, int columns, char** values, char** names)
 {
   if(columns != 7) {
     return 0;
@@ -126,6 +133,7 @@ static int cookieRowMapper(void* data, int columns,
   cookies.push_back(c);
   return 0;
 }
+} // namespace
 
 void Sqlite3CookieParser::parse(std::vector<Cookie>& cookies)
 {
