@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_URI_RESULT_H_
-#define _D_URI_RESULT_H_
+#ifndef D_URI_RESULT_H
+#define D_URI_RESULT_H
 
 #include "common.h"
 
@@ -66,4 +66,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_URI_RESULT_H_
+#endif // D_URI_RESULT_H
