@@ -32,14 +32,14 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _UT_METADATA_REQUEST_TRACKER_H_
-#define _UT_METADATA_REQUEST_TRACKER_H_
+#ifndef D_UT_METADATA_REQUEST_TRACKER_H
+#define D_UT_METADATA_REQUEST_TRACKER_H
 
 #include "common.h"
 
 #include <vector>
 
-#include "TimeA2.h"
+#include "TimerA2.h"
 #include "wallclock.h"
 
 namespace aria2 {
@@ -49,25 +49,25 @@ class Logger;
 class UTMetadataRequestTracker {
 private:
   struct RequestEntry {
-    size_t _index;
-    Time _dispatchedTime;
+    size_t index_;
+    Timer dispatchedTime_;
 
-    RequestEntry(size_t index):_index(index) {}
+    RequestEntry(size_t index):index_(index) {}
 
     bool elapsed(time_t t) const
     {
-      return _dispatchedTime.difference(global::wallclock) >= t;
+      return dispatchedTime_.difference(global::wallclock) >= t;
     }
 
     bool operator==(const RequestEntry& e) const
     {
-      return _index == e._index;
+      return index_ == e.index_;
     }
   };
 
-  std::vector<RequestEntry> _trackedRequests;
+  std::vector<RequestEntry> trackedRequests_;
 
-  Logger* _logger;
+  Logger* logger_;
 public:
   UTMetadataRequestTracker();
 
@@ -89,7 +89,7 @@ public:
   // Returns the number of tracking list.
   size_t count() const
   {
-    return _trackedRequests.size();
+    return trackedRequests_.size();
   }
 
   // Returns the number of additional index this tracker can track.
@@ -98,4 +98,4 @@ public:
 
 } // namespace aria2
 
-#endif // _UT_METADATA_REQUEST_TRACKER_H_
+#endif // D_UT_METADATA_REQUEST_TRACKER_H
