@@ -37,11 +37,10 @@
 #include "util.h"
 #include "bittorrent_helper.h"
 #include "PeerStorage.h"
-#include "PeerListProcessor.h"
 #include "DlAbortEx.h"
 #include "message.h"
 #include "StringFormat.h"
-#include "bencode.h"
+#include "bencode2.h"
 #include "a2functional.h"
 #include "wallclock.h"
 
@@ -50,60 +49,84 @@ namespace aria2 {
 const std::string UTPexExtensionMessage::EXTENSION_NAME = "ut_pex";
 
 UTPexExtensionMessage::UTPexExtensionMessage(uint8_t extensionMessageID):
-  _extensionMessageID(extensionMessageID),
-  _interval(DEFAULT_INTERVAL),
-  _maxFreshPeer(DEFAULT_MAX_FRESH_PEER),
-  _maxDroppedPeer(DEFAULT_MAX_DROPPED_PEER) {}
+  extensionMessageID_(extensionMessageID),
+  interval_(DEFAULT_INTERVAL),
+  maxFreshPeer_(DEFAULT_MAX_FRESH_PEER),
+  maxDroppedPeer_(DEFAULT_MAX_DROPPED_PEER) {}
 
 UTPexExtensionMessage::~UTPexExtensionMessage() {}
 
 std::string UTPexExtensionMessage::getPayload()
 {
-  std::pair<std::string, std::string> freshPeerPair =
-    createCompactPeerListAndFlag(_freshPeers);
-  std::pair<std::string, std::string> droppedPeerPair =
-    createCompactPeerListAndFlag(_droppedPeers);
+  std::pair<std::pair<std::string, std::string>,
+            std::pair<std::string, std::string> > freshPeerPair =
+    createCompactPeerListAndFlag(freshPeers_);
+  std::pair<std::pair<std::string, std::string>,
+            std::pair<std::string, std::string> > droppedPeerPair =
+    createCompactPeerListAndFlag(droppedPeers_);
 
-  BDE dict = BDE::dict();
-  dict["added"] = freshPeerPair.first;
-  dict["added.f"] = freshPeerPair.second;
-  dict["dropped"] = droppedPeerPair.first;
-  return bencode::encode(dict);
+  Dict dict;
+  if(!freshPeerPair.first.first.empty()) {
+    dict.put("added", freshPeerPair.first.first);
+    dict.put("added.f", freshPeerPair.first.second);
+  }
+  if(!droppedPeerPair.first.first.empty()) {
+    dict.put("dropped", droppedPeerPair.first.first);
+  }
+  if(!freshPeerPair.second.first.empty()) {
+    dict.put("added6", freshPeerPair.second.first);
+    dict.put("added6.f", freshPeerPair.second.second);
+  }
+  if(!droppedPeerPair.second.first.empty()) {
+    dict.put("dropped6", droppedPeerPair.second.first);
+  }
+
+  return bencode2::encode(&dict);
 }
 
-std::pair<std::string, std::string>
+std::pair<std::pair<std::string, std::string>,
+          std::pair<std::string, std::string> >
 UTPexExtensionMessage::createCompactPeerListAndFlag
 (const std::vector<SharedHandle<Peer> >& peers)
 {
   std::string addrstring;
   std::string flagstring;
+  std::string addrstring6;
+  std::string flagstring6;
   for(std::vector<SharedHandle<Peer> >::const_iterator itr = peers.begin(),
         eoi = peers.end(); itr != eoi; ++itr) {
-    unsigned char compact[6];
-    if(bittorrent::createcompact(compact, (*itr)->ipaddr, (*itr)->port)) {
-      addrstring.append(&compact[0], &compact[6]);
-      flagstring += (*itr)->isSeeder() ? "2" : "0";
+    unsigned char compact[COMPACT_LEN_IPV6];
+    int compactlen = bittorrent::packcompact
+      (compact, (*itr)->getIPAddress(), (*itr)->getPort());
+    if(compactlen == COMPACT_LEN_IPV4) {
+      addrstring.append(&compact[0], &compact[compactlen]);
+      flagstring += (*itr)->isSeeder() ? 0x02u : 0x00u;
+    } else if(compactlen == COMPACT_LEN_IPV6) {
+      addrstring6.append(&compact[0], &compact[compactlen]);
+      flagstring6 += (*itr)->isSeeder() ? 0x02u : 0x00u;
     }
   }
-  return std::pair<std::string, std::string>(addrstring, flagstring);
+  return std::make_pair(std::make_pair(addrstring, flagstring),
+                        std::make_pair(addrstring6, flagstring6));
 }
 
 std::string UTPexExtensionMessage::toString() const
 {
-  return strconcat("ut_pex added=", util::uitos(_freshPeers.size()),
-                   ", dropped=", util::uitos(_droppedPeers.size()));
+  return strconcat("ut_pex added=", util::uitos(freshPeers_.size()),
+                   ", dropped=", util::uitos(droppedPeers_.size()));
 }
 
 void UTPexExtensionMessage::doReceivedAction()
 {
-  _peerStorage->addPeer(_freshPeers);
+  peerStorage_->addPeer(freshPeers_);
+  peerStorage_->addPeer(droppedPeers_);
 }
 
 bool UTPexExtensionMessage::addFreshPeer(const SharedHandle<Peer>& peer)
 {
   if(!peer->isIncomingPeer() &&
-     peer->getFirstContactTime().difference(global::wallclock) < _interval) {
-    _freshPeers.push_back(peer);
+     peer->getFirstContactTime().difference(global::wallclock) < interval_) {
+    freshPeers_.push_back(peer);
     return true;
   } else {
     return false;
@@ -112,15 +135,15 @@ bool UTPexExtensionMessage::addFreshPeer(const SharedHandle<Peer>& peer)
 
 bool UTPexExtensionMessage::freshPeersAreFull() const
 {
-  return _freshPeers.size() >= _maxFreshPeer;
+  return freshPeers_.size() >= maxFreshPeer_;
 }
 
 bool UTPexExtensionMessage::addDroppedPeer(const SharedHandle<Peer>& peer)
 {
   if(!peer->isIncomingPeer() &&
      peer->getBadConditionStartTime().
-     difference(global::wallclock) < _interval) {
-    _droppedPeers.push_back(peer);
+     difference(global::wallclock) < interval_) {
+    droppedPeers_.push_back(peer);
     return true;
   } else {
     return false;
@@ -129,23 +152,23 @@ bool UTPexExtensionMessage::addDroppedPeer(const SharedHandle<Peer>& peer)
 
 bool UTPexExtensionMessage::droppedPeersAreFull() const
 {
-  return _droppedPeers.size() >= _maxDroppedPeer;
+  return droppedPeers_.size() >= maxDroppedPeer_;
 }
 
 void UTPexExtensionMessage::setMaxFreshPeer(size_t maxFreshPeer)
 {
-  _maxFreshPeer = maxFreshPeer;
+  maxFreshPeer_ = maxFreshPeer;
 }
 
 void UTPexExtensionMessage::setMaxDroppedPeer(size_t maxDroppedPeer)
 {
-  _maxDroppedPeer = maxDroppedPeer;
+  maxDroppedPeer_ = maxDroppedPeer;
 }
 
 void UTPexExtensionMessage::setPeerStorage
 (const SharedHandle<PeerStorage>& peerStorage)
 {
-  _peerStorage = peerStorage;
+  peerStorage_ = peerStorage;
 }
 
 UTPexExtensionMessageHandle
@@ -153,21 +176,33 @@ UTPexExtensionMessage::create(const unsigned char* data, size_t len)
 {
   if(len < 1) {
     throw DL_ABORT_EX(StringFormat(MSG_TOO_SMALL_PAYLOAD_SIZE,
-                                   EXTENSION_NAME.c_str(), len).str());
+                                   EXTENSION_NAME.c_str(),
+                                   static_cast<unsigned long>(len)).str());
   }
   UTPexExtensionMessageHandle msg(new UTPexExtensionMessage(*data));
 
-  const BDE dict = bencode::decode(data+1, len-1);
-  if(dict.isDict()) {
-    PeerListProcessor proc;
-    const BDE& added = dict["added"];
-    if(added.isString()) {
-      proc.extractPeerFromCompact(added, std::back_inserter(msg->_freshPeers));
+  SharedHandle<ValueBase> decoded = bencode2::decode(data+1, len-1);
+  const Dict* dict = asDict(decoded);
+  if(dict) {
+    const String* added = asString(dict->get("added"));
+    if(added) {
+      bittorrent::extractPeer
+        (added, AF_INET,  std::back_inserter(msg->freshPeers_));
     }
-    const BDE& dropped = dict["dropped"];
-    if(dropped.isString()) {
-      proc.extractPeerFromCompact(dropped,
-                                  std::back_inserter(msg->_droppedPeers));
+    const String* dropped = asString(dict->get("dropped"));
+    if(dropped) {
+      bittorrent::extractPeer
+        (dropped, AF_INET, std::back_inserter(msg->droppedPeers_));
+    }
+    const String* added6 = asString(dict->get("added6"));
+    if(added6) {
+      bittorrent::extractPeer
+        (added6, AF_INET6, std::back_inserter(msg->freshPeers_));
+    }
+    const String* dropped6 = asString(dict->get("dropped6"));
+    if(dropped6) {
+      bittorrent::extractPeer
+        (dropped6, AF_INET6, std::back_inserter(msg->droppedPeers_));
     }
   }
   return msg;
