@@ -47,6 +47,7 @@ namespace aria2 {
 
 namespace xmlrpc {
 
+namespace {
 struct SessionData {
   XmlRpcRequestParserStateMachine* stm_;
 
@@ -54,9 +55,11 @@ struct SessionData {
 
   SessionData(XmlRpcRequestParserStateMachine* stm):stm_(stm) {}
 };
+} // namespace
 
-static void mlStartElement(void* userData, const xmlChar* name,
-                           const xmlChar** attrs)
+namespace {
+void mlStartElement(void* userData, const xmlChar* name,
+                    const xmlChar** attrs)
 {
   SessionData* sd = reinterpret_cast<SessionData*>(userData);
   std::map<std::string, std::string> attrmap;
@@ -68,7 +71,7 @@ static void mlStartElement(void* userData, const xmlChar* name,
       if(*p == 0) {
         break;
       }
-      std::string value = util::trim(reinterpret_cast<const char*>(*p));
+      std::string value = util::strip(reinterpret_cast<const char*>(*p));
       ++p;
       attrmap[name] = value;
     }
@@ -78,27 +81,33 @@ static void mlStartElement(void* userData, const xmlChar* name,
     sd->charactersStack_.push(std::string());
   }
 }
+} // namespace
 
-static void mlEndElement(void* userData, const xmlChar* name)
+namespace {
+void mlEndElement(void* userData, const xmlChar* name)
 {
   SessionData* sd = reinterpret_cast<SessionData*>(userData);
   std::string characters;
   if(sd->stm_->needsCharactersBuffering()) {
-    characters = util::trim(sd->charactersStack_.top());
+    characters = util::strip(sd->charactersStack_.top());
     sd->charactersStack_.pop();
   }
   sd->stm_->endElement(reinterpret_cast<const char*>(name), characters);
 }
+} // namespace
 
-static void mlCharacters(void* userData, const xmlChar* ch, int len)
+namespace {
+void mlCharacters(void* userData, const xmlChar* ch, int len)
 {
   SessionData* sd = reinterpret_cast<SessionData*>(userData);
   if(sd->stm_->needsCharactersBuffering()) {
     sd->charactersStack_.top() += std::string(&ch[0], &ch[len]);
   }
 }
+} // namespace
 
-static xmlSAXHandler mySAXHandler =
+namespace {
+xmlSAXHandler mySAXHandler =
   {
     0, // internalSubsetSAXFunc
     0, // isStandaloneSAXFunc
@@ -133,6 +142,7 @@ static xmlSAXHandler mySAXHandler =
     0, //   endElementNsSAX2Func
     0, //   xmlStructuredErrorFunc
   };
+} // namespace
 
 XmlRpcRequest
 XmlRpcRequestProcessor::parseMemory(const std::string& xml)
