@@ -54,48 +54,53 @@
 #include "magnet.h"
 #include "bencode2.h"
 #include "TorrentAttribute.h"
+#include "SocketCore.h"
+#include "Option.h"
+#include "prefs.h"
 
 namespace aria2 {
 
 namespace bittorrent {
 
-static const std::string C_NAME("name");
+namespace {
+const std::string C_NAME("name");
 
-static const std::string C_NAME_UTF8("name.utf-8");
+const std::string C_NAME_UTF8("name.utf-8");
 
-static const std::string C_FILES("files");
+const std::string C_FILES("files");
 
-static const std::string C_LENGTH("length");
+const std::string C_LENGTH("length");
 
-static const std::string C_PATH("path");
+const std::string C_PATH("path");
 
-static const std::string C_PATH_UTF8("path.utf-8");
+const std::string C_PATH_UTF8("path.utf-8");
 
-static const std::string C_INFO("info");
+const std::string C_INFO("info");
 
-static const std::string C_PIECES("pieces");
+const std::string C_PIECES("pieces");
 
-static const std::string C_PIECE_LENGTH("piece length");
+const std::string C_PIECE_LENGTH("piece length");
 
-static const std::string C_PRIVATE("private");
+const std::string C_PRIVATE("private");
 
-static const std::string C_URL_LIST("url-list");
+const std::string C_URL_LIST("url-list");
 
-static const std::string C_ANNOUNCE("announce");
+const std::string C_ANNOUNCE("announce");
 
-static const std::string C_ANNOUNCE_LIST("announce-list");
+const std::string C_ANNOUNCE_LIST("announce-list");
 
-static const std::string C_NODES("nodes");
+const std::string C_NODES("nodes");
 
-static const std::string C_CREATION_DATE("creation date");
+const std::string C_CREATION_DATE("creation date");
 
-static const std::string C_COMMENT("comment");
+const std::string C_COMMENT("comment");
 
-static const std::string C_COMMENT_UTF8("comment.utf-8");
+const std::string C_COMMENT_UTF8("comment.utf-8");
 
-static const std::string C_CREATED_BY("created by");
+const std::string C_CREATED_BY("created by");
 
-static const std::string DEFAULT_PEER_ID_PREFIX("aria2-");
+const std::string DEFAULT_PEER_ID_PREFIX("aria2-");
+} // namespace
 
 const std::string BITTORRENT("bittorrent");
 
@@ -103,10 +108,11 @@ const std::string MULTI("multi");
 
 const std::string SINGLE("single");
 
-static void extractPieceHash(const SharedHandle<DownloadContext>& ctx,
-                             const std::string& hashData,
-                             size_t hashLength,
-                             size_t numPieces)
+namespace {
+void extractPieceHash(const SharedHandle<DownloadContext>& ctx,
+                      const std::string& hashData,
+                      size_t hashLength,
+                      size_t numPieces)
 {
   std::vector<std::string> pieceHashes;
   pieceHashes.reserve(numPieces);
@@ -117,8 +123,10 @@ static void extractPieceHash(const SharedHandle<DownloadContext>& ctx,
   ctx->setPieceHashes(pieceHashes.begin(), pieceHashes.end());
   ctx->setPieceHashAlgo(MessageDigestContext::SHA1);
 }
+} // namespace
 
-static void extractUrlList
+namespace {
+void extractUrlList
 (const SharedHandle<TorrentAttribute>& torrent, std::vector<std::string>& uris,
  const ValueBase* v)
 {
@@ -159,9 +167,11 @@ static void extractUrlList
     v->accept(visitor);
   }
 }
+} // namespace
 
+namespace {
 template<typename InputIterator, typename OutputIterator>
-static OutputIterator createUri
+OutputIterator createUri
 (InputIterator first, InputIterator last, OutputIterator out,
  const std::string& filePath)
 {
@@ -174,8 +184,10 @@ static OutputIterator createUri
   }
   return out;
 }
+} // namespace
 
-static void extractFileEntries
+namespace {
+void extractFileEntries
 (const SharedHandle<DownloadContext>& ctx,
  const SharedHandle<TorrentAttribute>& torrent,
  const Dict* infoDict,
@@ -184,6 +196,7 @@ static void extractFileEntries
  const std::vector<std::string>& urlList)
 {
   std::string name;
+  std::string utf8Name;
   if(overrideName.empty()) {
     std::string nameKey;
     if(infoDict->containsKey(C_NAME_UTF8)) {
@@ -193,17 +206,18 @@ static void extractFileEntries
     }
     const String* nameData = asString(infoDict->get(nameKey));
     if(nameData) {
-      if(util::detectDirTraversal(nameData->s())) {
+      utf8Name = util::encodeNonUtf8(nameData->s());
+      if(util::detectDirTraversal(utf8Name)) {
         throw DL_ABORT_EX
           (StringFormat
            (MSG_DIR_TRAVERSAL_DETECTED,nameData->s().c_str()).str());
       }
       name = nameData->s();
     } else {
-      name = strconcat(File(defaultName).getBasename(), ".file");
+      name = utf8Name = strconcat(File(defaultName).getBasename(), ".file");
     }
   } else {
-    name = overrideName;
+    name = utf8Name = overrideName;
   }
   torrent->name = name;
   std::vector<SharedHandle<FileEntry> > fileEntries;
@@ -252,9 +266,11 @@ static void extractFileEntries
         }
       }
       std::string path = strjoin(pathelem.begin(), pathelem.end(), '/');
-      if(util::detectDirTraversal(path)) {
+      std::string utf8Path = strjoin(pathelem.begin(), pathelem.end(), '/',
+                                     std::ptr_fun(util::encodeNonUtf8));
+      if(util::detectDirTraversal(utf8Path)) {
         throw DL_ABORT_EX
-          (StringFormat(MSG_DIR_TRAVERSAL_DETECTED, path.c_str()).str());
+          (StringFormat(MSG_DIR_TRAVERSAL_DETECTED, utf8Path.c_str()).str());
       }
       std::string pePath =
         strjoin(pathelem.begin(), pathelem.end(), '/',
@@ -263,9 +279,8 @@ static void extractFileEntries
       std::vector<std::string> uris;
       createUri(urlList.begin(), urlList.end(),std::back_inserter(uris),pePath);
       SharedHandle<FileEntry> fileEntry
-        (new FileEntry(util::applyDir(ctx->getDir(), util::escapePath(path)),
-                       fileLengthData->i(),
-                       offset, uris));
+        (new FileEntry(util::applyDir(ctx->getDir(),util::escapePath(utf8Path)),
+                       fileLengthData->i(), offset, uris));
       fileEntry->setOriginalName(path);
       fileEntries.push_back(fileEntry);
       offset += fileEntry->getLength();
@@ -291,21 +306,21 @@ static void extractFileEntries
         uris.push_back(*i);
       }
     }
-
     SharedHandle<FileEntry> fileEntry
-      (new FileEntry(util::applyDir(ctx->getDir(), util::escapePath(name)),
-                     totalLength, 0,
-                     uris));
+      (new FileEntry(util::applyDir(ctx->getDir(), util::escapePath(utf8Name)),
+                     totalLength, 0, uris));
     fileEntry->setOriginalName(name);
     fileEntries.push_back(fileEntry);
   }
   ctx->setFileEntries(fileEntries.begin(), fileEntries.end());
   if(torrent->mode == MULTI) {
-    ctx->setBasePath(util::applyDir(ctx->getDir(), name));
+    ctx->setBasePath(util::applyDir(ctx->getDir(), utf8Name));
   }
 }
+} // namespace
 
-static void extractAnnounce
+namespace {
+void extractAnnounce
 (const SharedHandle<TorrentAttribute>& torrent, const Dict* rootDict)
 {
   const List* announceList = asList(rootDict->get(C_ANNOUNCE_LIST));
@@ -321,7 +336,7 @@ static void extractAnnounce
             eoi2 = tier->end(); uriIter != eoi2; ++uriIter) {
         const String* uri = asString(*uriIter);
         if(uri) {
-          ntier.push_back(util::trim(uri->s()));
+          ntier.push_back(util::strip(uri->s()));
         }
       }
       if(!ntier.empty()) {
@@ -332,13 +347,15 @@ static void extractAnnounce
     const String* announce = asString(rootDict->get(C_ANNOUNCE));
     if(announce) {
       std::vector<std::string> tier;
-      tier.push_back(util::trim(announce->s()));
+      tier.push_back(util::strip(announce->s()));
       torrent->announceList.push_back(tier);
     }
   }
 }
+} // namespace
 
-static void extractNodes
+namespace {
+void extractNodes
 (const SharedHandle<TorrentAttribute>& torrent, const ValueBase* nodesListSrc)
 {
   const List* nodesList = asList(nodesListSrc);
@@ -353,7 +370,7 @@ static void extractNodes
       if(!hostname) {
         continue;
       }
-      if(util::trim(hostname->s()).empty()) {
+      if(util::strip(hostname->s()).empty()) {
         continue;
       }
       const Integer* port = asInteger(addrPairList->get(1));
@@ -364,8 +381,10 @@ static void extractNodes
     }
   }
 }
+} // namespace
 
-static void processRootDictionary
+namespace {
+void processRootDictionary
 (const SharedHandle<DownloadContext>& ctx,
  const SharedHandle<ValueBase>& root,
  const std::string& defaultName,
@@ -470,6 +489,7 @@ static void processRootDictionary
 
   ctx->setAttribute(BITTORRENT, torrent);
 }
+} // namespace
 
 void load(const std::string& torrentFile,
           const SharedHandle<DownloadContext>& ctx,
@@ -573,14 +593,8 @@ void print(std::ostream& o, const SharedHandle<DownloadContext>& dctx)
     o << "Comment: " << torrentAttrs->comment << "\n";
   }
   if(torrentAttrs->creationDate) {
-    struct tm* staticNowtmPtr;
-    char buf[26];
-    time_t t = torrentAttrs->creationDate;
-    if((staticNowtmPtr = localtime(&t)) != 0 &&
-       asctime_r(staticNowtmPtr, buf) != 0) {
-      // buf includes "\n"
-      o << "Creation Date: " << buf;
-    }
+    o << "Creation Date: " << Time(torrentAttrs->creationDate).toHTTPDate()
+      << std::endl;
   }
   if(!torrentAttrs->createdBy.empty()) {
     o << "Created By: " << torrentAttrs->createdBy << "\n";
@@ -623,8 +637,9 @@ void computeFastSet
 (std::vector<size_t>& fastSet, const std::string& ipaddr,
  size_t numPieces, const unsigned char* infoHash, size_t fastSetSize)
 {
-  unsigned char compact[6];
-  if(!createcompact(compact, ipaddr, 0)) {
+  unsigned char compact[COMPACT_LEN_IPV6];
+  int compactlen = packcompact(compact, ipaddr, 0);
+  if(compactlen != COMPACT_LEN_IPV4) {
     return;
   }
   if(numPieces < fastSetSize) {
@@ -632,11 +647,11 @@ void computeFastSet
   }
   unsigned char tx[24];
   memcpy(tx, compact, 4);
-  if((tx[0] & 0x80) == 0 || (tx[0] & 0x40) == 0) {
-    tx[2] = 0x00;
-    tx[3] = 0x00;
+  if((tx[0] & 0x80u) == 0 || (tx[0] & 0x40u) == 0) {
+    tx[2] = 0x00u;
+    tx[3] = 0x00u;
   } else {
-    tx[3] = 0x00;
+    tx[3] = 0x00u;
   }
   memcpy(tx+4, infoHash, 20);
   unsigned char x[20];
@@ -672,7 +687,9 @@ std::string generatePeerId(const std::string& peerIdPrefix)
   return peerId;
 }
 
-static std::string peerId;
+namespace {
+std::string peerId;
+} // namespace
 
 const std::string& generateStaticPeerId(const std::string& peerIdPrefix)
 {
@@ -801,57 +818,70 @@ void createPeerMessageString
   msg[4] = messageId;
 }
 
-bool createcompact
+int packcompact
 (unsigned char* compact, const std::string& addr, uint16_t port)
 {
-  struct addrinfo hints;
   struct addrinfo* res;
-  memset(&hints, 0, sizeof(hints));
-  hints.ai_family = AF_INET; // since compact peer format is ipv4 only.
-  hints.ai_flags = AI_NUMERICHOST;
-  if(getaddrinfo(addr.c_str(), 0, &hints, &res)) {
-    return false;
+  int s =
+    callGetaddrinfo(&res, addr.c_str(), 0, AF_UNSPEC, 0, AI_NUMERICHOST, 0);
+  if(s != 0) {
+    return 0;
   }
-  struct sockaddr_in* in = reinterpret_cast<struct sockaddr_in*>(res->ai_addr);
-  memcpy(compact, &(in->sin_addr.s_addr), sizeof(uint32_t));
-  uint16_t port_nworder(htons(port));
-  memcpy(compact+4, &port_nworder, sizeof(uint16_t));
-  freeaddrinfo(res);
-  return true;
+  WSAAPI_AUTO_DELETE<struct addrinfo*> resDeleter(res, freeaddrinfo);
+  uint16_t portN = htons(port);
+  for(struct addrinfo* rp = res; rp; rp = rp->ai_next) {
+    if(rp->ai_family == AF_INET) {
+      struct sockaddr_in* in =
+        reinterpret_cast<struct sockaddr_in*>(res->ai_addr);
+      memcpy(compact, &(in->sin_addr), 4);
+      memcpy(compact+4, &portN, sizeof(portN));
+      return COMPACT_LEN_IPV4;
+    } else if(rp->ai_family == AF_INET6) {
+      struct sockaddr_in6* in6 =
+        reinterpret_cast<struct sockaddr_in6*>(res->ai_addr);
+      memcpy(compact, &(in6->sin6_addr), 16);
+      memcpy(compact+16, &portN, sizeof(portN));
+      return COMPACT_LEN_IPV6;
+    }
+  }
+  return 0;
 }
 
-std::pair<std::string, uint16_t> unpackcompact(const unsigned char* compact)
+std::pair<std::string, uint16_t> unpackcompact
+(const unsigned char* compact, int family)
 {
-  struct sockaddr_in in;
-  memset(&in, 0, sizeof(in));
-#ifdef HAVE_SOCKADDR_IN_SIN_LEN
-  // For netbsd
-  in.sin_len = sizeof(in);
-#endif // HAVE_SOCKADDR_IN_SIN_LEN
-  in.sin_family = AF_INET;
-  memcpy(&(in.sin_addr.s_addr), compact, sizeof(uint32_t));
-  in.sin_port = 0;
-  char host[NI_MAXHOST];
-  int s;
-  s = getnameinfo(reinterpret_cast<const struct sockaddr*>(&in), sizeof(in),
-                  host, NI_MAXHOST, 0, 0,
-                  NI_NUMERICHOST);
-  if(s) {
-    return std::pair<std::string, uint16_t>();
+  std::pair<std::string, uint16_t> r;
+#ifdef HAVE_INET_NTOP
+  int portOffset = family == AF_INET?4:16;
+  char buf[INET6_ADDRSTRLEN];
+  if(!inet_ntop(family, compact, buf, sizeof(buf))) {
+    return r;
   }
-  uint16_t port_nworder;
-  memcpy(&port_nworder, compact+sizeof(uint32_t), sizeof(uint16_t));
-  uint16_t port = ntohs(port_nworder);
-  return std::make_pair(host, port);
+  r.first = buf;
+  uint16_t portN;
+  memcpy(&portN, compact+portOffset, sizeof(portN));
+  r.second = ntohs(portN);
+#else // !HAVE_INET_NTOP
+  if(family != AF_INET) {
+    return r;
+  }
+  struct in_addr addr;
+  memcpy(&addr, compact, sizeof(in_addr));
+  r.first = inet_ntoa(addr);
+  uint16_t portN;
+  memcpy(&portN, compact+4, sizeof(portN));
+  r.second = ntohs(portN);
+#endif // !HAVE_INET_NTOP
+  return r;
 }
 
-
 void assertPayloadLengthGreater
 (size_t threshold, size_t actual, const std::string& msgName)
 {
   if(actual <= threshold) {
     throw DL_ABORT_EX
-      (StringFormat(MSG_TOO_SMALL_PAYLOAD_SIZE, msgName.c_str(), actual).str());
+      (StringFormat(MSG_TOO_SMALL_PAYLOAD_SIZE, msgName.c_str(),
+                    static_cast<unsigned long>(actual)).str());
   }
 }
 
@@ -861,7 +891,8 @@ void assertPayloadLengthEqual
   if(expected != actual) {
     throw DL_ABORT_EX
       (StringFormat(EX_INVALID_PAYLOAD_SIZE, msgName.c_str(),
-                    actual, expected).str());
+                    static_cast<unsigned long>(actual),
+                    static_cast<unsigned long>(expected)).str());
   }
 }
 
@@ -992,6 +1023,71 @@ std::string torrent2Magnet(const SharedHandle<TorrentAttribute>& attrs)
   return uri;
 }
 
+int getCompactLength(int family)
+{
+  if(family == AF_INET) {
+    return COMPACT_LEN_IPV4;
+  } else if(family == AF_INET6) {
+    return COMPACT_LEN_IPV6;
+  } else {
+    return 0;
+  }
+}
+
+void removeAnnounceUri
+(const SharedHandle<TorrentAttribute>& attrs,
+ const std::vector<std::string>& uris)
+{
+  if(uris.empty()) {
+    return;
+  }
+  if(std::find(uris.begin(), uris.end(), "*") == uris.end()) {
+    for(std::vector<std::vector<std::string> >::iterator i =
+          attrs->announceList.begin(); i != attrs->announceList.end();) {
+      for(std::vector<std::string>::iterator j =(*i).begin();j != (*i).end();) {
+        if(std::find(uris.begin(), uris.end(), *j) == uris.end()) {
+          ++j;
+        } else {
+          j = (*i).erase(j);
+        }
+      }
+      if((*i).empty()) {
+        i = attrs->announceList.erase(i);
+      } else {
+        ++i;
+      }
+    }
+  } else {
+    attrs->announceList.clear();
+  }
+}
+
+void addAnnounceUri
+(const SharedHandle<TorrentAttribute>& attrs,
+ const std::vector<std::string>& uris)
+{
+  for(std::vector<std::string>::const_iterator i = uris.begin(),
+        eoi = uris.end(); i != eoi; ++i) {
+    std::vector<std::string> tier;
+    tier.push_back(*i);
+    attrs->announceList.push_back(tier);
+  }
+}
+
+void adjustAnnounceUri
+(const SharedHandle<TorrentAttribute>& attrs,
+ const SharedHandle<Option>& option)
+{
+  std::vector<std::string> excludeUris;
+  std::vector<std::string> addUris;
+  util::split(option->get(PREF_BT_EXCLUDE_TRACKER),
+              std::back_inserter(excludeUris), A2STR::COMMA_C, true);
+  util::split(option->get(PREF_BT_TRACKER),
+              std::back_inserter(addUris), A2STR::COMMA_C, true);
+  removeAnnounceUri(attrs, excludeUris);
+  addAnnounceUri(attrs, addUris);
+}
+
 } // namespace bittorrent
 
 } // namespace aria2
