@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DOWNLOAD_HELPER_H_
-#define _D_DOWNLOAD_HELPER_H_
+#ifndef D_DOWNLOAD_HELPER_H
+#define D_DOWNLOAD_HELPER_H
 
 #include "common.h"
 
@@ -47,19 +47,24 @@ namespace aria2 {
 
 class RequestGroup;
 class Option;
+class MetadataInfo;
+class DownloadContext;
 
 const std::set<std::string>& listRequestOptions();
 
 #ifdef ENABLE_BITTORRENT
 // Create RequestGroup object using torrent file specified by
 // torrent-file option.  If non-empty torrentData is specified, then
-// it is used as a content of torrent file instead. In this function,
+// it is used as a content of torrent file instead. If
+// adjustAnnounceUri is true, announce URIs are adjusted using
+// bittorrent::adjustAnnounceUri().  In this function,
 // force-sequential is ignored.
 void createRequestGroupForBitTorrent
 (std::vector<SharedHandle<RequestGroup> >& result,
  const SharedHandle<Option>& option,
  const std::vector<std::string>& uris,
- const std::string& torrentData = "");
+ const std::string& torrentData = "",
+ bool adjustAnnounceUri = true);
 #endif // ENABLE_BITTORRENT
 
 #ifdef ENABLE_METALINK
@@ -90,6 +95,18 @@ void createRequestGroupForUri
  bool ignoreForceSequential = false,
  bool ignoreLocalPath = false);
 
+template<typename InputIterator>
+void setMetadataInfo
+(InputIterator first, InputIterator last, const SharedHandle<MetadataInfo>& mi)
+{
+  for(; first != last; ++first) {
+    (*first)->setMetadataInfo(mi);
+  }
+}
+
+SharedHandle<MetadataInfo>
+createMetadataInfoFromFirstFileEntry(const SharedHandle<DownloadContext>& dctx);
+
 } // namespace aria2
 
-#endif // _D_DOWNLOAD_HELPER_H_
+#endif // D_DOWNLOAD_HELPER_H
